@@ -62,6 +62,9 @@ __workers__ = []
 __telegrambot_name__ = 'ht-bot'
 __telegrambot_token__ = ''
 
+global __is_all_loaded__
+__is_all_loaded__ = False
+
 def __checkLibraryUpdate__():
     try:
         # Check Version Update
@@ -125,9 +128,12 @@ def getModule(moduleName):
 
     # While the mods are loading with workers, wait por it
     while any( [ work.startswith('import-module-') for work in getWorkers() ] ):
-        print('loading... please wait')
         __sleep(0.1)
 
+    while not __is_all_loaded__:
+        print('loading modules yet, please wait')
+        __sleep(0.3)
+
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
@@ -589,6 +595,8 @@ def __importModules__():
                 except Exception as e:
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
+    global __is_all_loaded__
+    __is_all_loaded__ = True
 
 worker('check-library-updated', 'ht.__checkLibraryUpdate__', loop=False, run_until_ht_stops=True, log=__amidjango__)
 worker('refresh-pool-servers', 'ht.Pool.__checkPoolNodes__', timesleep=180, run_until_ht_stops=True, log=__amidjango__)
